From: Dhruv Chawla <[email protected]>
Signed-off-by: Dhruv Chawla <[email protected]>
gcc/ChangeLog:
* emit-rtl.h (struct rtl_data): Fix typos.
(struct address_reload_context): Likewise.
* explow.cc (anti_adjust_stack_and_probe): Likewise.
* explow.h (anti_adjust_stack_and_probe_stack_clash): Likewise.
* expmed.cc (store_bit_field_using_insv): Likewise.
(expand_mult): Likewise.
(emit_store_flag_force): Likewise.
(equivalent_cmp_code): Likewise.
* expr.cc (class op_by_pieces_d): Likewise.
(op_by_pieces_d::run): Likewise.
(use_group_regs): Likewise.
(get_def_for_expr): Likewise.
(emit_move_insn): Likewise.
(expand_expr_real): Likewise.
(expand_expr_real_gassign): Likewise.
* ext-dce.cc (ext_dce_process_uses): Likewise.
(ext_dce_process_bb): Likewise.
(ext_dce_rd_confluence_n): Likewise.
* fibonacci_heap.h (fibonacci_heap::cut): Likewise.
* fold-const.cc (combine_comparisons): Likewise.
(operand_compare::operand_equal_p): Likewise.
(fold_view_convert_vector_encoding): Likewise.
(fold_truth_andor): Likewise.
* fold-const.h: Likewise.
* function.cc (temp_address_hasher::equal): Likewise.
(gen_call_used_regs_seq): Likewise.
* gcc-diagnostic-spec.cc (GTY): Likewise.
(warning_suppressed_at): Likewise.
* gcc.cc (driver::maybe_run_linker): Likewise.
* gcov.cc (print_usage): Likewise.
(strip_extention): Likewise.
* gdbhooks.py: Likewise.
* gimplify.cc (gimplify_decl_expr): Likewise.
(gimplify_modify_expr): Likewise.
(oacc_default_clause): Likewise.
(omp_notice_variable): Likewise.
* graph.cc (draw_cfg_nodes): Likewise.
* graphite-dependences.cc (scop_get_reads_and_writes): Likewise.
* graphite-isl-ast-to-gimple.cc (graphite_copy_stmts_from_block):
Likewise.
* haifa-sched.cc (model_set_excess_costs): Likewise.
(analyze_set_insn_for_autopref): Likewise.
(autopref_multipass_dfa_lookahead_guard): Likewise.
* hash-map-traits.h (HASH_MAP_TRAITS_H): Likewise.
* hosthooks.h (struct host_hooks): Likewise.
* ifcvt.cc (noce_try_sign_bit_splat): Likewise.
* input.cc (line_table_test::line_table_test): Likewise.
* internal-fn.def (PHI): Likewise.
* internal-fn.h (enum ifn_goacc_loop_kind): Likewise.
* ira-build.cc (create_insn_allocnos): Likewise.
* ira-color.cc (ira_mark_new_stack_slot): Likewise.
* ira-int.h: Likewise.
* ira.cc (struct sloc): Likewise.
* json-parsing.cc (parser::require_one_of): Likewise.
* langhooks.h (struct lang_hooks_for_decls): Likewise.
* libgdiagnostics.cc: Likewise.
* libgdiagnostics.h (diagnostic_manager_write_patch): Likewise.
* loop-invariant.cc (MAX_CANON_ADDR_PARTS): Likewise.
* lra-assigns.cc (reload_pseudo_compare_func): Likewise.
* lra-constraints.cc (match_reload): Likewise.
(process_alt_operands): Likewise.
(process_address_1): Likewise.
(lra_constraints): Likewise.
(inherit_in_ebb): Likewise.
* lra-eliminations.cc (init_elim_table): Likewise.
* lra-remat.cc: Likewise.
* machmode.h (struct int_n_data_t): Likewise.
* mem-stats.h (mem_alloc_description::register_descriptor): Likewise.
(mem_alloc_description::unregister_descriptor): Likewise.
* mode-switching.cc (optimize_mode_switching): Likewise.
* modulo-sched.cc (schedule_reg_moves): Likewise.
(optimize_sc): Likewise.
---
gcc/emit-rtl.h | 4 ++--
gcc/explow.cc | 2 +-
gcc/explow.h | 2 +-
gcc/expmed.cc | 8 ++++----
gcc/expr.cc | 14 +++++++-------
gcc/ext-dce.cc | 6 +++---
gcc/fibonacci_heap.h | 6 +++---
gcc/fold-const.cc | 12 ++++++------
gcc/fold-const.h | 2 +-
gcc/function.cc | 4 ++--
gcc/gcc-diagnostic-spec.cc | 4 ++--
gcc/gcc.cc | 10 +++++-----
gcc/gcov.cc | 6 +++---
gcc/gdbhooks.py | 4 ++--
gcc/gimplify.cc | 8 ++++----
gcc/graph.cc | 2 +-
gcc/graphite-dependences.cc | 12 ++++++------
gcc/graphite-isl-ast-to-gimple.cc | 2 +-
gcc/haifa-sched.cc | 6 +++---
gcc/hash-map-traits.h | 2 +-
gcc/hosthooks.h | 2 +-
gcc/ifcvt.cc | 4 ++--
gcc/input.cc | 2 +-
gcc/internal-fn.def | 4 ++--
gcc/internal-fn.h | 2 +-
gcc/ira-build.cc | 2 +-
gcc/ira-color.cc | 2 +-
gcc/ira-int.h | 2 +-
gcc/ira.cc | 2 +-
gcc/json-parsing.cc | 2 +-
gcc/langhooks.h | 2 +-
gcc/libgdiagnostics.cc | 2 +-
gcc/libgdiagnostics.h | 2 +-
gcc/loop-invariant.cc | 2 +-
gcc/lra-assigns.cc | 2 +-
gcc/lra-constraints.cc | 16 ++++++++--------
gcc/lra-eliminations.cc | 2 +-
gcc/lra-remat.cc | 4 ++--
gcc/machmode.h | 2 +-
gcc/mem-stats.h | 12 ++++++------
gcc/mode-switching.cc | 2 +-
gcc/modulo-sched.cc | 4 ++--
42 files changed, 96 insertions(+), 96 deletions(-)
diff --git a/gcc/emit-rtl.h b/gcc/emit-rtl.h
index c498a8689bc..0b572580a98 100644
--- a/gcc/emit-rtl.h
+++ b/gcc/emit-rtl.h
@@ -89,7 +89,7 @@ struct GTY(()) rtl_data {
rtx return_rtx;
/* Vector of initial-value pairs. Each pair consists of a pseudo
- register of approprite mode that stores the initial value a hard
+ register of appropriate mode that stores the initial value a hard
register REGNO, and that hard register itself. */
/* ??? This could be a VEC but there is currently no way to define an
opaque VEC type. */
@@ -527,7 +527,7 @@ extern rtx adjust_automodify_address_1 (rtx, machine_mode,
rtx,
how reload pseudos are created. */
struct address_reload_context
{
- /* Can be overriden by derived classes. */
+ /* Can be overridden by derived classes. */
virtual rtx get_reload_reg () const { return gen_reg_rtx (Pmode); }
/* Emit insns to reload VALUE into a new register. VALUE is an
diff --git a/gcc/explow.cc b/gcc/explow.cc
index 755c1d2e6dc..2529d0bd0cb 100644
--- a/gcc/explow.cc
+++ b/gcc/explow.cc
@@ -2202,7 +2202,7 @@ anti_adjust_stack_and_probe (rtx size, bool adjust_back)
{
/* We skip the probe for the first interval + a small dope of 4 words and
probe that many bytes past the specified size to maintain a protection
- area at the botton of the stack. */
+ area at the bottom of the stack. */
const int dope = 4 * UNITS_PER_WORD;
/* First ensure SIZE is Pmode. */
diff --git a/gcc/explow.h b/gcc/explow.h
index 75672f11d7e..67b29a57c18 100644
--- a/gcc/explow.h
+++ b/gcc/explow.h
@@ -78,7 +78,7 @@ extern void anti_adjust_stack_and_probe (rtx, bool);
extern void anti_adjust_stack_and_probe_stack_clash (rtx);
/* Support for building allocation/probing loops for stack-clash
- protection of dyamically allocated stack space. */
+ protection of dynamically allocated stack space. */
extern void compute_stack_clash_protection_loop_data (rtx *, rtx *, rtx *,
HOST_WIDE_INT *, rtx);
extern void emit_stack_clash_protection_probe_loop_start (rtx *, rtx *,
diff --git a/gcc/expmed.cc b/gcc/expmed.cc
index fe39506b6bd..3e8a6affde7 100644
--- a/gcc/expmed.cc
+++ b/gcc/expmed.cc
@@ -663,7 +663,7 @@ store_bit_field_using_insv (const extraction_insn *insv,
rtx op0,
/* There are similar overflow check at the start of store_bit_field_1,
but that only check the situation where the field lies completely
outside the register, while there do have situation where the field
- lies partialy in the register, we need to adjust bitsize for this
+ lies partially in the register, we need to adjust bitsize for this
partial overflow situation. Without this fix, pr48335-2.c on big-endian
will broken on those arch support bit insert instruction, like arm,
aarch64
etc. */
@@ -3545,7 +3545,7 @@ expand_mult (machine_mode mode, rtx op0, rtx op1, rtx
target,
/* If mode is integer vector mode, check if the backend supports
vector lshift (by scalar or vector) at all. If not, we can't use
- synthetized multiply. */
+ synthesized multiply. */
if (GET_MODE_CLASS (mode) == MODE_VECTOR_INT
&& optab_handler (vashl_optab, mode) == CODE_FOR_nothing
&& optab_handler (ashl_optab, mode) == CODE_FOR_nothing)
@@ -6309,7 +6309,7 @@ emit_store_flag_force (rtx target, enum rtx_code code,
rtx op0, rtx op1,
}
/* Expand a vector (left) rotate of MODE of X by an immediate AMT as a vector
- permute operation. Emit code to put the result in DST if successfull and
+ permute operation. Emit code to put the result in DST if successful and
return it. Otherwise return NULL. This is intended to implement vector
rotates by byte amounts using vector permutes when the target does not offer
native vector rotate operations. */
@@ -6384,7 +6384,7 @@ equivalent_cmp_code (enum rtx_code code)
}
}
-/* Choose the more appropiate immediate in scalar integer comparisons. The
+/* Choose the more appropriate immediate in scalar integer comparisons. The
purpose of this is to end up with an immediate which can be loaded into a
register in fewer moves, if possible.
diff --git a/gcc/ext-dce.cc b/gcc/ext-dce.cc
index d75f7e48574..d567f08a970 100644
--- a/gcc/ext-dce.cc
+++ b/gcc/ext-dce.cc
@@ -1153,7 +1153,7 @@ ext_dce_process_uses (rtx_insn *insn, rtx obj,
&& GET_MODE_BITSIZE (outer_mode) <= HOST_BITS_PER_WIDE_INT)
{
/* So we have a right shift that could correspond to
- the second in a pair impementing QI, HI or SI -> DI
+ the second in a pair implementing QI, HI or SI -> DI
extension. See if we can find the left shift. For
now, just look one real instruction back. */
rtx_insn *prev_insn = prev_nonnote_nondebug_insn_bb (insn);
@@ -1399,7 +1399,7 @@ ext_dce_process_bb (basic_block bb)
if (!FAKE_CALL_P (insn))
bitmap_set_range (livenow, STACK_POINTER_REGNUM * 4, 4);
- /* If this is not a call to a const fucntion, then assume it
+ /* If this is not a call to a const function, then assume it
can read any global register. */
if (!RTL_CONST_CALL_P (insn))
for (unsigned i = 0; i < FIRST_PSEUDO_REGISTER; i++)
@@ -1664,7 +1664,7 @@ ext_dce_rd_transfer_n (int bb_index)
/* Dummy function for the df_simple_dataflow API. */
static bool ext_dce_rd_confluence_n (edge) { return true; }
-/* Use lifetime analyis to identify extensions that set bits that
+/* Use lifetime analysis to identify extensions that set bits that
are never read. Turn such extensions into SUBREGs instead which
can often be propagated away. */
diff --git a/gcc/fibonacci_heap.h b/gcc/fibonacci_heap.h
index 7df659fb857..079759a2856 100644
--- a/gcc/fibonacci_heap.h
+++ b/gcc/fibonacci_heap.h
@@ -258,7 +258,7 @@ private:
/* Remove NODE from PARENT's child list. */
void cut (fibonacci_node_t *node, fibonacci_node_t *parent);
- /* Process cut of node Y and do it recursivelly. */
+ /* Process cut of node Y and do it recursively. */
void cascading_cut (fibonacci_node_t *y);
/* Extract minimum node from the heap. */
@@ -281,7 +281,7 @@ private:
/* Allocator used to hold nodes. */
pool_allocator *m_allocator;
- /* True if alocator is owned by the current heap only. */
+ /* True if allocator is owned by the current heap only. */
bool m_own_allocator;
};
@@ -569,7 +569,7 @@ fibonacci_heap<K,V>::cut (fibonacci_node<K,V> *node,
node->m_mark = 0;
}
-/* Process cut of node Y and do it recursivelly. */
+/* Process cut of node Y and do it recursively. */
template<class K, class V>
void
diff --git a/gcc/fold-const.cc b/gcc/fold-const.cc
index a7351445eac..8a2ab86454b 100644
--- a/gcc/fold-const.cc
+++ b/gcc/fold-const.cc
@@ -3192,7 +3192,7 @@ combine_comparisons (location_t loc,
compares equal.
Unless OEP_MATCH_SIDE_EFFECTS is set, the function returns false on
- any operand with side effect. This is unnecesarily conservative in the
+ any operand with side effect. This is unnecessarily conservative in the
case we know that arg0 and arg1 are in disjoint code paths (such as in
?: operator). In addition OEP_MATCH_SIDE_EFFECTS is used when comparing
addresses with TREE_CONSTANT flag set so we know that &var == &var
@@ -3375,7 +3375,7 @@ operand_compare::operand_equal_p (tree type0, const_tree
arg0,
return false;
}
- /* When not checking adddresses, this is needed for conversions and for
+ /* When not checking addresses, this is needed for conversions and for
COMPONENT_REF. Might as well play it safe and always test this. */
if (TREE_CODE (type0) == ERROR_MARK
|| TREE_CODE (type1) == ERROR_MARK
@@ -3742,7 +3742,7 @@ operand_compare::operand_equal_p (tree type0, const_tree
arg0,
case WIDEN_MULT_MINUS_EXPR:
if (!OP_SAME (2))
return false;
- /* The multiplcation operands are commutative. */
+ /* The multiplication operands are commutative. */
/* FALLTHRU */
case TRUTH_AND_EXPR:
@@ -3764,7 +3764,7 @@ operand_compare::operand_equal_p (tree type0, const_tree
arg0,
return OP_SAME (0);
case BIT_INSERT_EXPR:
- /* BIT_INSERT_EXPR has an implict operand as the type precision
+ /* BIT_INSERT_EXPR has an implicit operand as the type precision
of op1. Need to check to make sure they are the same. */
if (TREE_CODE (TREE_OPERAND (arg0, 1)) == INTEGER_CST
&& TREE_CODE (TREE_OPERAND (arg1, 1)) == INTEGER_CST
@@ -9098,7 +9098,7 @@ fold_view_convert_vector_encoding (tree type, tree expr)
!= (int) buffer_bytes)
return NULL_TREE;
- /* Reencode the bytes as TYPE. */
+ /* Re-encode the bytes as TYPE. */
unsigned int type_npatterns = type_sequence_bits / type_elt_bits;
return native_interpret_vector_part (type, &buffer[0], buffer.length (),
type_npatterns, nelts_per_pattern);
@@ -9752,7 +9752,7 @@ fold_truth_andor (location_t loc, enum tree_code code,
tree type,
}
/* Transform (A AND-IF B) into (A AND B), or (A OR-IF B)
into (A OR B).
- For sequence point consistancy, we need to check for trapping,
+ For sequence point consistency, we need to check for trapping,
and side-effects. */
else if (code == icode && simple_condition_p (arg0)
&& simple_condition_p (arg1))
diff --git a/gcc/fold-const.h b/gcc/fold-const.h
index 37303147773..f70f21c2654 100644
--- a/gcc/fold-const.h
+++ b/gcc/fold-const.h
@@ -292,7 +292,7 @@ public:
protected:
/* Verify that when arguments (ARG0 and ARG1) are equal, then they have
an equal hash value. When the function knowns comparison return,
- true is returned. Then RET is set to corresponding comparsion result. */
+ true is returned. Then RET is set to corresponding comparison result. */
bool verify_hash_value (const_tree arg0, const_tree arg1, unsigned int flags,
bool *ret);
diff --git a/gcc/function.cc b/gcc/function.cc
index 109821c16fc..5ade058d724 100644
--- a/gcc/function.cc
+++ b/gcc/function.cc
@@ -708,7 +708,7 @@ temp_address_hasher::equal (temp_slot_address_entry *t1,
return exp_equiv_p (t1->address, t2->address, 0, true);
}
-/* Add ADDRESS as an alias of TEMP_SLOT to the addess -> temp slot mapping. */
+/* Add ADDRESS as an alias of TEMP_SLOT to the address -> temp slot mapping.
*/
static void
insert_temp_slot_address (rtx address, class temp_slot *temp_slot)
{
@@ -5932,7 +5932,7 @@ gen_call_used_regs_seq (rtx_insn *ret, unsigned int
zero_regs_type)
1. it is a call-used register;
and 2. it is not a fixed register;
and 3. it is not live at the return of the routine;
- and 4. it is general registor if only_gpr is true;
+ and 4. it is general register if only_gpr is true;
and 5. it is used in the routine if only_used is true;
and 6. it is a register that passes parameter if only_arg is true. */
diff --git a/gcc/gcc-diagnostic-spec.cc b/gcc/gcc-diagnostic-spec.cc
index 813625e2877..8c91f81505f 100644
--- a/gcc/gcc-diagnostic-spec.cc
+++ b/gcc/gcc-diagnostic-spec.cc
@@ -121,7 +121,7 @@ nowarn_spec_t::nowarn_spec_t (opt_code opt)
GTY(()) nowarn_map_t *nowarn_map;
/* Return the no-warning disposition for location LOC and option OPT
- or for all/any otions by default. */
+ or for all/any options by default. */
bool
warning_suppressed_at (location_t loc, opt_code opt /* = all_warnings */)
@@ -140,7 +140,7 @@ warning_suppressed_at (location_t loc, opt_code opt /* =
all_warnings */)
return false;
}
- /* Change the supression of warnings for location LOC.
+ /* Change the suppression of warnings for location LOC.
OPT controls which warnings are affected.
The wildcard OPT of -1 controls all warnings.
If SUPP is true (the default), enable the suppression of the warnings.
diff --git a/gcc/gcc.cc b/gcc/gcc.cc
index 43b0158ee02..feefa0d48f3 100644
--- a/gcc/gcc.cc
+++ b/gcc/gcc.cc
@@ -63,7 +63,7 @@ compilation is specified by a string called a "spec". */
/* Manage the manipulation of env vars.
- We poison "getenv" and "putenv", so that all enviroment-handling is
+ We poison "getenv" and "putenv", so that all environment-handling is
done through this class. Note that poisoning happens in the
preprocessor at the identifier level, and doesn't distinguish between
env.getenv ();
@@ -607,7 +607,7 @@ or with constant text in a single argument.
%2 process CC1PLUS_SPEC as a spec.
%* substitute the variable part of a matched option. (See below.)
Note that each comma in the substituted string is replaced by
- a single space. A space is appended after the last substition
+ a single space. A space is appended after the last substitution
unless there is more text in current sequence.
%<S remove all occurrences of -S from the command line.
Note - this command is position dependent. % commands in the
@@ -643,7 +643,7 @@ or with constant text in a single argument.
if %* appears somewhere in X, then X will be substituted
once for each matching switch, with the %* replaced by the
part of that switch that matched the '*'. A space will be
- appended after the last substition unless there is more
+ appended after the last substitution unless there is more
text in current sequence.
%{.S:X} substitutes X, if processing a file with suffix S.
%{!.S:X} substitutes X, if NOT processing a file with suffix S.
@@ -1094,7 +1094,7 @@ proper position among the other output files. */
/* Conditional to test whether the LTO plugin is used or not.
FIXME: For slim LTO we will need to enable plugin unconditionally. This
still cause problems with PLUGIN_LD != LD and when plugin is built but
- not useable. For GCC 4.6 we don't support slim LTO and thus we can enable
+ not usable. For GCC 4.6 we don't support slim LTO and thus we can enable
plugin only when LTO is enabled. We still honor explicit
-fuse-linker-plugin if the linker used understands -plugin. */
@@ -9339,7 +9339,7 @@ driver::maybe_run_linker (const char *argv0) const
warning (0, "%s: linker input file unused because linking not done",
outfiles[i]);
if (access (outfiles[i], F_OK) < 0)
- /* This is can be an indication the user specifed an errorneous
+ /* This is can be an indication the user specified an erroneous
separated option value, (or used the wrong prefix for an
option). */
error ("%s: linker input file not found: %m", outfiles[i]);
diff --git a/gcc/gcov.cc b/gcc/gcov.cc
index 80acb7986d9..9dc39fc3235 100644
--- a/gcc/gcov.cc
+++ b/gcc/gcov.cc
@@ -694,7 +694,7 @@ static int flag_long_names = 0;
static int flag_hash_filenames = 0;
-/* Print verbose informations. */
+/* Print verbose information. */
static int flag_verbose = 0;
@@ -1134,7 +1134,7 @@ print_usage (int error_p)
fnotice (file, " -t, --stdout Output to stdout instead
of a file\n");
fnotice (file, " -u, --unconditional-branches Show unconditional branch
counts too\n");
fnotice (file, " -v, --version Print version number, then
exit\n");
- fnotice (file, " -w, --verbose Print verbose
informations\n");
+ fnotice (file, " -w, --verbose Print verbose
information\n");
fnotice (file, " -x, --hash-filenames Hash long pathnames\n");
fnotice (file, "\nObsolete options:\n");
fnotice (file, " -i, --json-format Replaced with -j,
--json-format\n");
@@ -1459,7 +1459,7 @@ strip_extention (string str)
return str;
}
-/* Calcualte md5sum for INPUT string and return it in hex string format. */
+/* Calculate md5sum for INPUT string and return it in hex string format. */
static string
get_md5sum (const char *input)
diff --git a/gcc/gdbhooks.py b/gcc/gdbhooks.py
index bf4bc724c34..616fc605f62 100644
--- a/gcc/gdbhooks.py
+++ b/gcc/gdbhooks.py
@@ -200,7 +200,7 @@ class Tree:
def IDENTIFIER_POINTER(self):
"""
- Get str correspoinding to result of IDENTIFIER_NODE (self)
+ Get str corresponding to result of IDENTIFIER_NODE (self)
"""
return self.gdbval['identifier']['id']['str'].string()
@@ -816,7 +816,7 @@ class DumpFn(gdb.Command):
else:
flags = 0
- # Get tempory file, if necessary
+ # Get temporary file, if necessary
if editor_mode:
f = tempfile.NamedTemporaryFile(delete=False, suffix=".txt")
filename = f.name
diff --git a/gcc/graph.cc b/gcc/graph.cc
index 2eb47b92e15..8c62cf4d9ee 100644
--- a/gcc/graph.cc
+++ b/gcc/graph.cc
@@ -255,7 +255,7 @@ draw_cfg_nodes (pretty_printer *pp, struct function *fun)
draw_cfg_nodes_no_loops (pp, fun);
}
-/* Draw all edges in the CFG. Retreating edges are drawin as not
+/* Draw all edges in the CFG. Retreating edges are drawn as not
constraining, this makes the layout of the graph better. */
static void
diff --git a/gcc/graphite-dependences.cc b/gcc/graphite-dependences.cc
index d2f750c615e..0693f87f4e3 100644
--- a/gcc/graphite-dependences.cc
+++ b/gcc/graphite-dependences.cc
@@ -82,7 +82,7 @@ scop_get_reads_and_writes (scop_p scop, isl_union_map *&reads,
{
if (dump_file)
{
- fprintf (dump_file, "Adding read to depedence graph: ");
+ fprintf (dump_file, "Adding read to dependence graph: ");
print_pdr (dump_file, pdr);
}
isl_union_map *um
@@ -90,7 +90,7 @@ scop_get_reads_and_writes (scop_p scop, isl_union_map *&reads,
reads = isl_union_map_union (reads, um);
if (dump_file)
{
- fprintf (dump_file, "Reads depedence graph: ");
+ fprintf (dump_file, "Reads dependence graph: ");
print_isl_union_map (dump_file, reads);
}
}
@@ -98,7 +98,7 @@ scop_get_reads_and_writes (scop_p scop, isl_union_map *&reads,
{
if (dump_file)
{
- fprintf (dump_file, "Adding must write to depedence graph: ");
+ fprintf (dump_file, "Adding must write to dependence graph: ");
print_pdr (dump_file, pdr);
}
isl_union_map *um
@@ -106,7 +106,7 @@ scop_get_reads_and_writes (scop_p scop, isl_union_map
*&reads,
must_writes = isl_union_map_union (must_writes, um);
if (dump_file)
{
- fprintf (dump_file, "Must writes depedence graph: ");
+ fprintf (dump_file, "Must writes dependence graph: ");
print_isl_union_map (dump_file, must_writes);
}
}
@@ -114,7 +114,7 @@ scop_get_reads_and_writes (scop_p scop, isl_union_map
*&reads,
{
if (dump_file)
{
- fprintf (dump_file, "Adding may write to depedence graph: ");
+ fprintf (dump_file, "Adding may write to dependence graph: ");
print_pdr (dump_file, pdr);
}
isl_union_map *um
@@ -122,7 +122,7 @@ scop_get_reads_and_writes (scop_p scop, isl_union_map
*&reads,
may_writes = isl_union_map_union (may_writes, um);
if (dump_file)
{
- fprintf (dump_file, "May writes depedence graph: ");
+ fprintf (dump_file, "May writes dependence graph: ");
print_isl_union_map (dump_file, may_writes);
}
}
diff --git a/gcc/graphite-isl-ast-to-gimple.cc
b/gcc/graphite-isl-ast-to-gimple.cc
index d8de78a3ed0..cfdde6ed073 100644
--- a/gcc/graphite-isl-ast-to-gimple.cc
+++ b/gcc/graphite-isl-ast-to-gimple.cc
@@ -1147,7 +1147,7 @@ void translate_isl_ast_to_gimple::
graphite_copy_stmts_from_block (basic_block bb, basic_block new_bb,
vec<tree> iv_map)
{
- /* Iterator poining to the place where new statement (s) will be inserted.
*/
+ /* Iterator pointing to the place where new statement (s) will be inserted.
*/
gimple_stmt_iterator gsi_tgt = gsi_last_bb (new_bb);
for (gimple_stmt_iterator gsi = gsi_start_bb (bb); !gsi_end_p (gsi);
diff --git a/gcc/haifa-sched.cc b/gcc/haifa-sched.cc
index 58cda3af839..879749e9785 100644
--- a/gcc/haifa-sched.cc
+++ b/gcc/haifa-sched.cc
@@ -2545,7 +2545,7 @@ model_set_excess_costs (rtx_insn **insns, int count)
if (!param_cycle_accurate_model)
return;
- /* Use MAX (baseECC, 0) and baseP to calculcate ECC for each
+ /* Use MAX (baseECC, 0) and baseP to calculate ECC for each
instruction. */
for (i = 0; i < count; i++)
{
@@ -5608,7 +5608,7 @@ analyze_set_insn_for_autopref (rtx pat, bool write, rtx
*base, int *offset)
/* Functions to model cache auto-prefetcher.
Some of the CPUs have cache auto-prefetcher, which /seems/ to initiate
- memory prefetches if it sees instructions with consequitive memory accesses
+ memory prefetches if it sees instructions with consecutive memory accesses
in the instruction stream. Details of such hardware units are not
published,
so we can only guess what exactly is going on there.
In the scheduler, we model abstract auto-prefetcher. If there are memory
@@ -5805,7 +5805,7 @@ autopref_multipass_dfa_lookahead_guard (rtx_insn *insn1,
int ready_index)
if (ready_index == 0
&& data1->status == AUTOPREF_MULTIPASS_DATA_DONT_DELAY)
- /* We allow only a single delay on priviledged instructions.
+ /* We allow only a single delay on privileged instructions.
Doing otherwise would cause infinite loop. */
{
if (sched_verbose >= 2)
diff --git a/gcc/hash-map-traits.h b/gcc/hash-map-traits.h
index 8dfa519846a..25153b6d8fc 100644
--- a/gcc/hash-map-traits.h
+++ b/gcc/hash-map-traits.h
@@ -20,7 +20,7 @@ along with GCC; see the file COPYING3. If not see
#ifndef HASH_MAP_TRAITS_H
#define HASH_MAP_TRAITS_H
-/* Bacause mem-stats.h uses default hashmap traits, we have to
+/* Because mem-stats.h uses default hashmap traits, we have to
put the class to this separate header file. */
#include "hash-traits.h"
diff --git a/gcc/hosthooks.h b/gcc/hosthooks.h
index fce41d63712..877a2d18ff5 100644
--- a/gcc/hosthooks.h
+++ b/gcc/hosthooks.h
@@ -30,7 +30,7 @@ struct host_hooks
void * (*gt_pch_get_address) (size_t size, int fd);
/* ADDR is an address returned by gt_pch_get_address. Attempt to allocate
- SIZE bytes at the same address (preferrably) or some other address
+ SIZE bytes at the same address (preferably) or some other address
and load it with the data from FD at OFFSET. Return -1 if we couldn't
allocate memory, otherwise update ADDR to the actual address where it got
allocated, return 0 if the memory is allocated but the data not loaded,
diff --git a/gcc/ifcvt.cc b/gcc/ifcvt.cc
index c151146c1b2..c80a02b2255 100644
--- a/gcc/ifcvt.cc
+++ b/gcc/ifcvt.cc
@@ -1287,7 +1287,7 @@ noce_try_sign_bit_splat (struct noce_if_info *if_info)
goto fail;
}
- /* Since we know the value is currenly -1 or 0, some constants may
+ /* Since we know the value is currently -1 or 0, some constants may
be more easily handled by shifting the value again. A right
logical shift constructs 2^n-1 constants a left shift constructs
~(2^n-1) constants. Given some targets don't have efficient
@@ -1339,7 +1339,7 @@ noce_try_sign_bit_splat (struct noce_if_info *if_info)
goto fail;
}
- /* Since we know the value is currenly -1 or 0, some constants may
+ /* Since we know the value is currently -1 or 0, some constants may
be more easily handled by shifting the value again. A right
logical shift constructs 2^n-1 constants a left shift constructs
~(2^n-1) constants. Given some targets don't have efficient
diff --git a/gcc/input.cc b/gcc/input.cc
index 1ef3c5fdb5b..0bb4c8bafe6 100644
--- a/gcc/input.cc
+++ b/gcc/input.cc
@@ -1276,7 +1276,7 @@ line_table_test::line_table_test ()
}
/* Constructor. Store the old value of line_table, and create a new
- one, using the sitation described in CASE_. */
+ one, using the situation described in CASE_. */
line_table_test::line_table_test (const line_table_case &case_)
{
diff --git a/gcc/internal-fn.def b/gcc/internal-fn.def
index 084a9271631..d214ee46b4f 100644
--- a/gcc/internal-fn.def
+++ b/gcc/internal-fn.def
@@ -129,7 +129,7 @@ along with GCC; see the file COPYING3. If not see
- The other is COND_LEN_* operations that are predicated by mask and len
both. Such operations only make sense for vectors.
- DEF_INTERNAL_SIGNED_COND_FN is like DEF_INTERNAL_COND_FN but defines intenal
+ DEF_INTERNAL_SIGNED_COND_FN is like DEF_INTERNAL_COND_FN but defines
internal
functions with DEF_INTERNAL_SIGNED_OPTAB_FN.
Each entry must have a corresponding expander of the form:
@@ -534,7 +534,7 @@ DEF_INTERNAL_FN (RAWMEMCHR, ECF_PURE | ECF_LEAF |
ECF_NOTHROW, NULL)
DEF_INTERNAL_FN (UNIQUE, ECF_NOTHROW, NULL)
DEF_INTERNAL_FN (PHI, 0, NULL)
-/* A function to represent an artifical initialization to an uninitialized
+/* A function to represent an artificial initialization to an uninitialized
automatic variable. */
DEF_INTERNAL_FN (DEFERRED_INIT, ECF_CONST | ECF_LEAF | ECF_NOTHROW, NULL)
diff --git a/gcc/internal-fn.h b/gcc/internal-fn.h
index b97c0dc6031..5e7cb73f0a3 100644
--- a/gcc/internal-fn.h
+++ b/gcc/internal-fn.h
@@ -88,7 +88,7 @@ enum ifn_goacc_loop_kind {
LEVEL corresponds to the GOMP_DIM of the reduction
OP is the tree code of the reduction operation
OFFSET may be used as an offset into a reduction array for the
- reductions occuring at this level.
+ reductions occurring at this level.
In general the return value is LOCAL_VAR, which creates a data
dependency between calls operating on the same reduction. */
diff --git a/gcc/ira-build.cc b/gcc/ira-build.cc
index 68c6d129056..bd3f1d36ac8 100644
--- a/gcc/ira-build.cc
+++ b/gcc/ira-build.cc
@@ -1854,7 +1854,7 @@ create_insn_allocnos (rtx x, rtx outer, bool output_p)
a = ira_create_allocno (regno, false, ira_curr_loop_tree_node);
/* This used to only trigger at allocno creation which seems
- wrong. We care about the WMODE propery across all the uses. */
+ wrong. We care about the WMODE property across all the uses. */
if (outer != NULL && GET_CODE (outer) == SUBREG)
{
machine_mode wmode = GET_MODE (outer);
diff --git a/gcc/ira-color.cc b/gcc/ira-color.cc
index 953dbd94ad8..447ea31f4a3 100644
--- a/gcc/ira-color.cc
+++ b/gcc/ira-color.cc
@@ -5115,7 +5115,7 @@ ira_mark_new_stack_slot (rtx x, int regno, poly_uint64
total_size)
given IN and OUT for INSN. Return also number points (through
EXCESS_PRESSURE_LIVE_LENGTH) where the pseudo-register lives and
the register pressure is high, number of references of the
- pseudo-registers (through NREFS), the number of psuedo registers
+ pseudo-registers (through NREFS), the number of pseudo registers
whose allocated register wouldn't need saving in the prologue
(through CALL_USED_COUNT), and the first hard regno occupied by the
pseudo-registers (through FIRST_HARD_REGNO). */
diff --git a/gcc/ira-int.h b/gcc/ira-int.h
index 6726a0f4cad..778c7afe694 100644
--- a/gcc/ira-int.h
+++ b/gcc/ira-int.h
@@ -937,7 +937,7 @@ public:
/* Flag of that the above array has been initialized. */
bool x_ira_prohibited_mode_move_regs_initialized_p;
- /* Number of real occurences of hard regs before IRA. */
+ /* Number of real occurrences of hard regs before IRA. */
size_t x_ira_hard_regno_nrefs[FIRST_PSEUDO_REGISTER];
};
diff --git a/gcc/ira.cc b/gcc/ira.cc
index 85c7ec419b3..f1beb7b300f 100644
--- a/gcc/ira.cc
+++ b/gcc/ira.cc
@@ -5384,7 +5384,7 @@ struct sloc
{
rtx_insn *insn; /* Insn where the scratch was. */
int nop; /* Number of the operand which was a scratch. */
- unsigned regno; /* regno gnerated instead of scratch */
+ unsigned regno; /* regno generated instead of scratch */
int icode; /* Original icode from which scratch was removed. */
};
diff --git a/gcc/json-parsing.cc b/gcc/json-parsing.cc
index 88c515e3f86..acbcff8ed44 100644
--- a/gcc/json-parsing.cc
+++ b/gcc/json-parsing.cc
@@ -1330,7 +1330,7 @@ parser::require_one_of (enum token_id tok_id_a, enum
token_id tok_id_b)
return result<enum token_id, std::unique_ptr<error>> (id);
}
-/* Genarate a parsing error. */
+/* Generate a parsing error. */
std::unique_ptr<error>
parser::error_at (const location_map::range &r, const char *fmt, ...)
diff --git a/gcc/langhooks.h b/gcc/langhooks.h
index cfcb38092d5..a34803ec786 100644
--- a/gcc/langhooks.h
+++ b/gcc/langhooks.h
@@ -254,7 +254,7 @@ struct lang_hooks_for_decls
/* Check whether this DECL belongs to a Fortran optional argument.
With 'for_present_check' set to false, decls which are optional parameters
- themselve are returned as tree - or a NULL_TREE otherwise. Those decls are
+ themselves are returned as tree - or a NULL_TREE otherwise. Those decls
are
always pointers. With 'for_present_check' set to true, the decl for
checking whether an argument is present is returned; for arguments with
value attribute this is the hidden argument and of BOOLEAN_TYPE. If the
diff --git a/gcc/libgdiagnostics.cc b/gcc/libgdiagnostics.cc
index 1cf451273d0..3e61322541a 100644
--- a/gcc/libgdiagnostics.cc
+++ b/gcc/libgdiagnostics.cc
@@ -553,7 +553,7 @@ public:
diagnostic_initialize (&m_dc, 0);
m_dc.remove_all_output_sinks ();
- /* Get defaults from environemt. These might be
+ /* Get defaults from environment. These might be
overridden by individual sinks. */
diagnostic_color_init (&m_dc, DIAGNOSTICS_COLOR_AUTO);
diagnostic_urls_init (&m_dc);
diff --git a/gcc/libgdiagnostics.h b/gcc/libgdiagnostics.h
index 137a35463f8..a20cd628b2d 100644
--- a/gcc/libgdiagnostics.h
+++ b/gcc/libgdiagnostics.h
@@ -386,7 +386,7 @@ diagnostic_manager_write_patch (diagnostic_manager
*diag_mgr,
If SARIF_SOURCE_LANGUAGE is non-NULL, it specifies a "sourceLanguage"
value for the file when use when writing SARIF.
See SARIF v2.1.0 Appendix J for suggested values for various
- programmming languages. */
+ programming languages. */
extern diagnostic_file *
diagnostic_manager_new_file (diagnostic_manager *diag_mgr,
diff --git a/gcc/loop-invariant.cc b/gcc/loop-invariant.cc
index c2622861ceb..8b82cdfbd7c 100644
--- a/gcc/loop-invariant.cc
+++ b/gcc/loop-invariant.cc
@@ -802,7 +802,7 @@ canonicalize_address_mult (rtx x)
#define MAX_CANON_ADDR_PARTS (5)
-/* Collect sub expressions in address X with PLUS as the seperator.
+/* Collect sub expressions in address X with PLUS as the separator.
Sub expressions are stored in vector ADDR_PARTS. */
static void
diff --git a/gcc/lra-assigns.cc b/gcc/lra-assigns.cc
index ddc685ecdfa..a9d2b5fc114 100644
--- a/gcc/lra-assigns.cc
+++ b/gcc/lra-assigns.cc
@@ -224,7 +224,7 @@ reload_pseudo_compare_func (const void *v1p, const void
*v2p)
if ((diff = regno_assign_info[r1].first - regno_assign_info[r2].first) != 0)
return diff;
/* Prefer pseudos with longer live ranges. It sets up better
- prefered hard registers for the thread pseudos and decreases
+ preferred hard registers for the thread pseudos and decreases
register-register moves between the thread pseudos. */
if ((diff = regno_live_length[r2] - regno_live_length[r1]) != 0)
return diff;
diff --git a/gcc/lra-constraints.cc b/gcc/lra-constraints.cc
index d6056cf7acc..9664b9165f6 100644
--- a/gcc/lra-constraints.cc
+++ b/gcc/lra-constraints.cc
@@ -1140,10 +1140,10 @@ match_reload (signed char out, signed char *ins, signed
char *outs,
4. asm ("" : "=r" (subreg:si(t:di,4)) : "0" (t:di))
5. i:si = subreg:si(t:di,4);
If we assign hard reg of x to t, dead code elimination
- will remove insn #2 and we will use unitialized hard reg.
+ will remove insn #2 and we will use uninitialized hard reg.
So exclude the hard reg of x for t. We could ignore this
problem for non-empty asm using all x value but it is hard to
- check that the asm are expanded into insn realy using x
+ check that the asm are expanded into insn really using x
and setting r. */
CLEAR_HARD_REG_SET (temp_hard_reg_set);
if (exclude_start_hard_regs != NULL)
@@ -2310,7 +2310,7 @@ process_alt_operands (int only_alternative)
->operand_alternative[nalt * n_operands + nop].reject);
if (lra_dump_file != NULL && inc != 0)
fprintf (lra_dump_file,
- " Staticly defined alt reject+=%d\n", inc);
+ " Statically defined alt reject+=%d\n", inc);
static_reject += inc;
matching_early_clobber[nop] = 0;
}
@@ -2820,7 +2820,7 @@ process_alt_operands (int only_alternative)
else
{
/* Prefer won reg to spilled pseudo under other
- equal conditions for possibe inheritance. */
+ equal conditions for possible inheritance. */
if (! scratch_p)
{
if (lra_dump_file != NULL)
@@ -3148,7 +3148,7 @@ process_alt_operands (int only_alternative)
if (lra_dump_file != NULL)
fprintf
(lra_dump_file,
- " %d Non-prefered reload: reject+=%d\n",
+ " %d Non-preferred reload: reject+=%d\n",
nop, LRA_MAX_REJECT);
reject += LRA_MAX_REJECT;
}
@@ -4147,7 +4147,7 @@ process_address_1 (int nop, bool check_only_p,
Index part of address may become invalid. For example, we
changed pseudo on the equivalent memory and a subreg of the
pseudo onto the memory of different mode for which the scale is
- prohibitted. */
+ prohibited. */
new_reg = index_part_to_reg (&ad, index_cl);
*ad.inner = simplify_gen_binary (PLUS, GET_MODE (new_reg),
*ad.base_term, new_reg);
@@ -5581,7 +5581,7 @@ lra_constraints (bool first_p)
check_and_force_assignment_correctness_p = true;
new_insn_uid_start = get_max_uid ();
new_regno_start = first_p ? lra_constraint_new_regno_start : max_reg_num ();
- /* Mark used hard regs for target stack size calulations. */
+ /* Mark used hard regs for target stack size calculations. */
for (i = FIRST_PSEUDO_REGISTER; i < new_regno_start; i++)
if (lra_reg_info[i].nrefs != 0
&& (hard_regno = lra_get_regno_hard_regno (i)) >= 0)
@@ -7479,7 +7479,7 @@ inherit_in_ebb (rtx_insn *head, rtx_insn *tail)
|| BLOCK_FOR_INSN (prev_insn) != curr_bb)
{
/* We reached the beginning of the current block -- do
- rest of spliting in the current BB. */
+ rest of splitting in the current BB. */
to_process = df_get_live_in (curr_bb);
if (BLOCK_FOR_INSN (head) != curr_bb)
{
diff --git a/gcc/lra-eliminations.cc b/gcc/lra-eliminations.cc
index 84954d5bd1c..571c17cf648 100644
--- a/gcc/lra-eliminations.cc
+++ b/gcc/lra-eliminations.cc
@@ -1327,7 +1327,7 @@ init_elim_table (void)
/* Build the FROM and TO REG rtx's. Note that code in gen_rtx_REG
will cause, e.g., gen_rtx_REG (Pmode, STACK_POINTER_REGNUM) to
- equal stack_pointer_rtx. We depend on this. Threfore we switch
+ equal stack_pointer_rtx. We depend on this. Therefore we switch
off that we are in LRA temporarily. */
lra_in_progress = false;
for (ep = reg_eliminate; ep < ®_eliminate[NUM_ELIMINABLE_REGS]; ep++)
diff --git a/gcc/lra-remat.cc b/gcc/lra-remat.cc
index 20d9f47d2e9..815fe187a73 100644
--- a/gcc/lra-remat.cc
+++ b/gcc/lra-remat.cc
@@ -80,7 +80,7 @@ typedef struct cand *cand_t;
typedef const struct cand *const_cand_t;
/* Insn candidates for rematerialization. The candidate insn should
- have the following properies:
+ have the following properties:
o no any memory (as access to memory is non-profitable) or
div/mod operations (as they are usually more expensive than loads)
o no INOUT regs (it means no non-paradoxical subreg of output reg)
@@ -131,7 +131,7 @@ public:
/* Registers becoming dead in the BB. */
bitmap_head dead_regs;
/* Cands present in the BB whose in/out regs are not changed after
- the cands occurence and are not dead (except the reload
+ the cands occurrence and are not dead (except the reload
regno). */
bitmap_head gen_cands;
bitmap_head livein_cands; /* cands whose inputs live at the BB start. */
diff --git a/gcc/machmode.h b/gcc/machmode.h
index 8d20bdebd4d..343782eff8f 100644
--- a/gcc/machmode.h
+++ b/gcc/machmode.h
@@ -1024,7 +1024,7 @@ HWI_COMPUTABLE_MODE_P (scalar_int_mode mode)
}
struct int_n_data_t {
- /* These parts are initailized by genmodes output */
+ /* These parts are initialized by genmodes output */
unsigned int bitsize;
scalar_int_mode_pod m;
/* RID_* is RID_INTN_BASE + index into this array */
diff --git a/gcc/mem-stats.h b/gcc/mem-stats.h
index 1cd5caa61c6..ab8d5ca4e5a 100644
--- a/gcc/mem-stats.h
+++ b/gcc/mem-stats.h
@@ -113,7 +113,7 @@ public:
/* File name of source code. */
const char *m_filename;
- /* Funcation name. */
+ /* Function name. */
const char *m_function;
/* Line number in source code. */
int m_line;
@@ -259,7 +259,7 @@ public:
size_t m_instances;
};
-/* Memory usage pair that connectes memory usage and number
+/* Memory usage pair that connects memory usage and number
of allocated bytes. */
template <class T>
class mem_usage_pair
@@ -306,7 +306,7 @@ public:
typedef hash_map <const void *, std::pair<T *, size_t> >
reverse_object_map_t;
typedef std::pair <mem_location *, T *> mem_list_t;
- /* Default contructor. */
+ /* Default constructor. */
mem_alloc_description ();
/* Default destructor. */
@@ -323,7 +323,7 @@ public:
T *register_descriptor (const void *ptr, mem_location *location);
/* Register memory allocation descriptor for container PTR. ORIGIN
identifies
- type of container and GGC identifes if the allocation is handled in GGC
+ type of container and GGC identifies if the allocation is handled in GGC
memory. Each location is identified by file NAME, LINE in source code and
FUNCTION name. */
T *register_descriptor (const void *ptr, mem_alloc_origin origin,
@@ -434,7 +434,7 @@ mem_alloc_description<T>::register_descriptor (const void
*ptr,
}
/* Register memory allocation descriptor for container PTR. ORIGIN identifies
- type of container and GGC identifes if the allocation is handled in GGC
+ type of container and GGC identifies if the allocation is handled in GGC
memory. Each location is identified by file NAME, LINE in source code and
FUNCTION name. */
@@ -550,7 +550,7 @@ mem_alloc_description<T>::unregister_descriptor (void *ptr)
m_reverse_map->remove (ptr);
}
-/* Default contructor. */
+/* Default constructor. */
template <class T>
inline
diff --git a/gcc/mode-switching.cc b/gcc/mode-switching.cc
index 9a464f3693f..8483a828742 100644
--- a/gcc/mode-switching.cc
+++ b/gcc/mode-switching.cc
@@ -1156,7 +1156,7 @@ optimize_mode_switching (void)
return no_mode;
};
- /* intialize mode in/out availability for bb. */
+ /* initialize mode in/out availability for bb. */
if (!targetm.mode_switching.confluence)
{
info[bb->index].mode_out = modes_confluence (avout);
diff --git a/gcc/modulo-sched.cc b/gcc/modulo-sched.cc
index b908d0f1f2b..3845233107b 100644
--- a/gcc/modulo-sched.cc
+++ b/gcc/modulo-sched.cc
@@ -733,7 +733,7 @@ schedule_reg_moves (partial_schedule_ptr ps)
gcc_assert (set);
/* If the instruction contains auto-inc register then
validate that the regmov is being generated for the
- target regsiter rather then the inc'ed register. */
+ target register rather then the inc'ed register. */
gcc_assert (!autoinc_var_is_used_p (u->insn, e->dest->insn));
}
@@ -1066,7 +1066,7 @@ optimize_sc (partial_schedule_ptr ps, ddg_ptr g)
/* The branch was failed to be placed in row ii - 1.
Put it back in it's original place in the partial
- schedualing. */
+ scheduling. */
set_must_precede_follow (&tmp_follow, must_follow, &tmp_precede,
must_precede, branch_cycle, start, end,
step);
diff --git a/gcc/expr.cc b/gcc/expr.cc
index d59a5463de4..a4ccc607cfd 100644
--- a/gcc/expr.cc
+++ b/gcc/expr.cc
@@ -1383,7 +1383,7 @@ class op_by_pieces_d
/* The type of operation that we're performing. */
by_pieces_operation m_op;
- /* Virtual functions, overriden by derived classes for the specific
+ /* Virtual functions, overridden by derived classes for the specific
operation. */
virtual void generate (rtx, rtx, machine_mode) = 0;
virtual bool prepare_mode (machine_mode, unsigned int) = 0;
@@ -1565,7 +1565,7 @@ op_by_pieces_d::run ()
if (gap > 0)
{
/* If size of MODE > M_LEN, generate the last operation
- in MODE for the remaining bytes with ovelapping memory
+ in MODE for the remaining bytes with overlapping memory
from the previois operation. */
if (m_reverse)
m_offset += gap;
@@ -3817,7 +3817,7 @@ use_group_regs (rtx *call_fusage, rtx regs)
}
/* Return the defining gimple statement for SSA_NAME NAME if it is an
- assigment and the code of the expresion on the RHS is CODE. Return
+ assignment and the code of the expression on the RHS is CODE. Return
NULL otherwise. */
static gimple *
@@ -3838,7 +3838,7 @@ get_def_for_expr (tree name, enum tree_code code)
}
/* Return the defining gimple statement for SSA_NAME NAME if it is an
- assigment and the class of the expresion on the RHS is CLASS. Return
+ assignment and the class of the expression on the RHS is CLASS. Return
NULL otherwise. */
static gimple *
@@ -4660,7 +4660,7 @@ emit_move_insn (rtx x, rtx y)
auto candidate_mem_p = [&](machine_mode innermode, rtx mem) {
return (!targetm.can_change_mode_class (innermode, GET_MODE (mem),
ALL_REGS)
&& !push_operand (mem, GET_MODE (mem))
- /* Not a candiate if innermode requires too much alignment. */
+ /* Not a candidate if innermode requires too much alignment. */
&& (MEM_ALIGN (mem) >= GET_MODE_ALIGNMENT (innermode)
|| targetm.slow_unaligned_access (GET_MODE (mem),
MEM_ALIGN (mem))
@@ -9621,7 +9621,7 @@ expand_expr_real (tree exp, rtx target, machine_mode
tmode,
}
/* Try to expand the conditional expression which is represented by
- TREEOP0 ? TREEOP1 : TREEOP2 using conditonal moves. If it succeeds
+ TREEOP0 ? TREEOP1 : TREEOP2 using conditional moves. If it succeeds
return the rtl reg which represents the result. Otherwise return
NULL_RTX. */
@@ -11337,7 +11337,7 @@ expand_expr_real_gassign (gassign *g, rtx target,
machine_mode tmode,
case GIMPLE_BINARY_RHS:
ops.op1 = gimple_assign_rhs2 (g);
/* Try to expand conditonal compare. */
if (targetm.have_ccmp ())
{
gcc_checking_assert (targetm.gen_ccmp_next != NULL);
@@ -11337,7 +11337,7 @@ expand_expr_real_gassign (gassign *g, rtx target,
case GIMPLE_BINARY_RHS:
ops.op1 = gimple_assign_rhs2 (g);
- /* Try to expand conditonal compare. */
+ /* Try to expand conditional compare. */
if (targetm.have_ccmp ())
{
diff --git a/gcc/gimplify.cc b/gcc/gimplify.cc
index e4db4b1d9bd..61cc660086e 100644
--- a/gcc/gimplify.cc
+++ b/gcc/gimplify.cc
@@ -2221,7 +2221,7 @@ gimplify_decl_expr (tree *stmt_p, gimple_seq *seq_p)
walk_tree (&init, force_labels_r, NULL, NULL);
}
/* When there is no explicit initializer, if the user requested,
- We should insert an artifical initializer for this automatic
+ We should insert an artificial initializer for this automatic
variable. */
else if (var_needs_auto_init_p (decl)
&& !decl_had_value_expr_p)
@@ -7483,7 +7483,7 @@ gimplify_modify_expr (tree *expr_p, gimple_seq *pre_p,
gimple_seq *post_p,
return ret;
}
- /* In case of va_arg internal fn wrappped in a WITH_SIZE_EXPR, add the type
+ /* In case of va_arg internal fn wrapped in a WITH_SIZE_EXPR, add the type
size as argument to the call. */
if (TREE_CODE (*from_p) == WITH_SIZE_EXPR)
{
@@ -9201,7 +9201,7 @@ oacc_default_clause (struct gimplify_omp_ctx *ctx, tree
decl, unsigned flags)
/* For Fortran COMMON blocks, only used variables in those blocks are
transferred and remapped. The block itself will have a private clause to
- avoid transfering the data twice.
+ avoid transferring the data twice.
The hook evaluates to false by default. For a variable in Fortran's
COMMON
or EQUIVALENCE block, returns 'true' (as we have shared=false) - as only
the variables in such a COMMON/EQUIVALENCE block shall be privatized not
@@ -9321,7 +9321,7 @@ omp_notice_variable (struct gimplify_omp_ctx *ctx, tree
decl, bool in_code)
if (DECL_HAS_VALUE_EXPR_P (decl))
{
if (ctx->region_type & ORT_ACC)
/* For OpenACC, defer expansion of value to avoid transfering
privatized common block data instead of im-/explicitly
transferred variables which are in common blocks. */
;
@@ -9321,7 +9321,7 @@ omp_notice_variable (struct gimplify_omp_ctx *ctx, tree
{
if (ctx->region_type & ORT_ACC)
- /* For OpenACC, defer expansion of value to avoid transfering
+ /* For OpenACC, defer expansion of value to avoid transferring
privatized common block data instead of im-/explicitly
transferred variables which are in common blocks. */
--
2.43.0